function num2bip_test()
% Test function for NUM2BIP.
%
% (c) 2011-2024 Stephen Cobeldick
%
% See Also TESTFUN_PREFIX NUM2BIP BIP2NUM NUM2SIP SIP2NUM NUM2RKM RKM2NUM

fnh = @num2bip;
chk = testfun_prefix(fnh);
%
%% Help Examples %%
%
chk(1024, fnh, '1 Ki')
chk(10240,                 fnh, '10 Ki')
chk(1.024e4,               fnh, '10 Ki')
chk(pow2(10,10),           fnh, '10 Ki')
chk(10*2^10,               fnh, '10 Ki')
chk(10240, 4, true,        fnh, '10 kibi')
chk(10240, 4, false, true, fnh, '10.00 Ki')
chk(1023, 3, fnh, '1020 ')
chk(1023, 2, fnh, '1 Ki')
chk(pow2(19),           fnh, '512 Ki')
chk(pow2(19), [], 'Mi', fnh, '0.5 Mi')
chk(pow2(200,20), [], true, fnh, '200 mebi') % byte
chk(1234567890, 3, fnh, '1.15 Gi') % byte
chk(bip2num('9 Ti'), fnh, '9 Ti') % 9 tebi
%
%% Basic Edge Cases %%
%
chk(0, fnh, '0 ', false, 0,'')
chk(1, fnh, '1 ', false, 1,'')
chk(NaN, fnh, 'NaN ', false, NaN,'')
chk(+Inf, fnh, 'Inf ', false, +Inf,'')
chk(-Inf, fnh, '-Inf ', false, -Inf,'')
chk(eps(0), fnh, '4.9407e-324 ', false, 4.9407e-324,'')
chk(eps(1), fnh, '2.2204e-16 ', false, 2.2204e-16,'')
%
%% Rounding %%
%
% sgf == default
chk(999,      fnh, '999 ',  false,  999,'')
chk(999.9999, fnh, '1000 ', false, 1000,'')
chk(1000,     fnh, '1000 ', false, 1000,'')
% sgf == 6
chk(1023,        6, fnh, '1023 ', false, 1023,'')
chk(1023.9,      6, fnh, '1023.9 ', false, 1023.9,'')
chk(1023.99,     6, fnh, '1023.99 ', false, 1023.99,'')
chk(1023.999,    6, fnh, '0.999999 Ki', true, 0.999999,'Ki')
chk(1023.9999,   6, fnh, '1 Ki', true, 1,'Ki')
chk(1023.99999,  6, fnh, '1 Ki', true, 1,'Ki')
chk(1023.999999, 6, fnh, '1 Ki', true, 1,'Ki')
chk(1024,        6, fnh, '1 Ki', true, 1,'Ki')
chk(1023,        6, [], true, fnh, '1023.00 ', false, 1023,'')
chk(1023.9,      6, [], true, fnh, '1023.90 ', false, 1023.9,'')
chk(1023.99,     6, [], true, fnh, '1023.99 ', false, 1023.99,'')
chk(1023.999,    6, [], true, fnh, '0.999999 Ki', true, 0.999999,'Ki')
chk(1023.9999,   6, [], true, fnh, '1.00000 Ki', true, 1,'Ki')
chk(1023.99999,  6, [], true, fnh, '1.00000 Ki', true, 1,'Ki')
chk(1023.999999, 6, [], true, fnh, '1.00000 Ki', true, 1,'Ki')
chk(1024,        6, [], true, fnh, '1.00000 Ki', true, 1,'Ki')
% sgf == 1:9
chk(1023.999, 1, [], true, fnh, '1 Ki', true, 1,'Ki')
chk(1023.999, 2, [], true, fnh, '1.0 Ki', true, 1,'Ki')
chk(1023.999, 3, [], true, fnh, '1.00 Ki', true, 1,'Ki')
chk(1023.999, 4, [], true, fnh, '1.000 Ki', true, 1,'Ki')
chk(1023.999, 5, [], true, fnh, '1.0000 Ki', true, 1,'Ki')
chk(1023.999, 6, [], true, fnh, '0.999999 Ki', true, 0.999999,'Ki')
chk(1023.999, 7, [], true, fnh, '1023.999 ', false, 1023.999,'')
chk(1023.999, 8, [], true, fnh, '1023.9990 ', false, 1023.999,'')
chk(1023.999, 9, [], true, fnh, '1023.99900 ', false, 1023.999,'')
chk(10239.99, 1, [], true, fnh, '10 Ki', true, 10,'Ki')
chk(10239.99, 2, [], true, fnh, '10 Ki', true, 10,'Ki')
chk(10239.99, 3, [], true, fnh, '10.0 Ki', true, 10,'Ki')
chk(10239.99, 4, [], true, fnh, '10.00 Ki', true, 10,'Ki')
chk(10239.99, 5, [], true, fnh, '10.000 Ki', true, 10,'Ki')
chk(10239.99, 6, [], true, fnh, '9.99999 Ki', true, 9.99999,'Ki')
chk(10239.99, 7, [], true, fnh, '9.999990 Ki', true, 9.999990,'Ki')
chk(10239.99, 8, [], true, fnh, '9.9999902 Ki', true, 9.9999902,'Ki')
chk(10239.99, 9, [], true, fnh, '9.99999023 Ki', true, 9.99999023,'Ki')
chk(102399.9, 1, [], true, fnh, '100 Ki', true, 100,'Ki')
chk(102399.9, 2, [], true, fnh, '100 Ki', true, 100,'Ki')
chk(102399.9, 3, [], true, fnh, '100 Ki', true, 100,'Ki')
chk(102399.9, 4, [], true, fnh, '100.0 Ki', true, 100,'Ki')
chk(102399.9, 5, [], true, fnh, '100.00 Ki', true, 100,'Ki')
chk(102399.9, 6, [], true, fnh, '99.9999 Ki', true, 99.9999,'Ki')
chk(102399.9, 7, [], true, fnh, '99.99990 Ki', true, 99.99990,'Ki')
chk(102399.9, 8, [], true, fnh, '99.999902 Ki', true, 99.999902,'Ki')
chk(102399.9, 9, [], true, fnh, '99.9999023 Ki', true, 99.9999023,'Ki')
chk(1023999,  1, [], true, fnh, '1 Mi', true, 1,'Mi')
chk(1023999,  2, [], true, fnh, '1000 Ki', true, 1000,'Ki')
chk(1023999,  3, [], true, fnh, '1000 Ki', true, 1000,'Ki')
chk(1023999,  4, [], true, fnh, '1000 Ki', true, 1000,'Ki')
chk(1023999,  5, [], true, fnh, '1000.0 Ki',true, 1000,'Ki')
chk(1023999,  6, [], true, fnh, '999.999 Ki', true, 999.999,'Ki')
chk(1023999,  7, [], true, fnh, '999.9990 Ki', true, 999.9990,'Ki')
chk(1023999,  8, [], true, fnh, '999.99902 Ki', true, 999.99902,'Ki')
chk(1023999,  9, [], true, fnh, '999.999023 Ki', true, 999.999023,'Ki')
chk(pow2(20)-1, 1, [], true, fnh, '1 Mi', true, 1,'Mi')
chk(pow2(20)-1, 2, [], true, fnh, '1.0 Mi', true, 1,'Mi')
chk(pow2(20)-1, 3, [], true, fnh, '1.00 Mi', true, 1,'Mi')
chk(pow2(20)-1, 4, [], true, fnh, '1.000 Mi', true, 1,'Mi')
chk(pow2(20)-1, 5, [], true, fnh, '1.0000 Mi', true, 1,'Mi')
chk(pow2(20)-1, 6, [], true, fnh, '0.999999 Mi', true, 0.999999,'Mi')
chk(pow2(20)-1, 7, [], true, fnh, '1023.999 Ki', true, 1023.999,'Ki')
chk(pow2(20)-1, 8, [], true, fnh, '1023.9990 Ki', true, 1023.9990,'Ki')
chk(pow2(20)-1, 9, [], true, fnh, '1023.99902 Ki', true, 1023.99902,'Ki')
%
%% One Less Than %%
%
% 1024^0 == pow2(0)
chk(pow2(1e0,0)-1, 1, fnh, '0 ', false, 0,'')
chk(pow2(1e0,0)-1, 2, fnh, '0 ', false, 0,'')
chk(pow2(1e0,0)-1, 3, fnh, '0 ', false, 0,'')
chk(pow2(1e0,0)-1, 4, fnh, '0 ', false, 0,'')
chk(pow2(1e0,0)-1, 5, fnh, '0 ', false, 0,'')
chk(pow2(1e0,0)-1, 6, fnh, '0 ', false, 0,'')
chk(pow2(1e0,0)-1, 7, fnh, '0 ', false, 0,'')
chk(pow2(1e0,0)-1, 8, fnh, '0 ', false, 0,'')
chk(pow2(1e0,0)-1, 9, fnh, '0 ', false, 0,'')
chk(pow2(1e1,0)-1, 1, fnh, '9 ', false, 9,'')
chk(pow2(1e1,0)-1, 2, fnh, '9 ', false, 9,'')
chk(pow2(1e1,0)-1, 3, fnh, '9 ', false, 9,'')
chk(pow2(1e1,0)-1, 4, fnh, '9 ', false, 9,'')
chk(pow2(1e1,0)-1, 5, fnh, '9 ', false, 9,'')
chk(pow2(1e1,0)-1, 6, fnh, '9 ', false, 9,'')
chk(pow2(1e1,0)-1, 7, fnh, '9 ', false, 9,'')
chk(pow2(1e1,0)-1, 8, fnh, '9 ', false, 9,'')
chk(pow2(1e1,0)-1, 9, fnh, '9 ', false, 9,'')
chk(pow2(1e2,0)-1, 1, fnh, '100 ', false, 100,'')
chk(pow2(1e2,0)-1, 2, fnh, '99 ', false, 99,'')
chk(pow2(1e2,0)-1, 3, fnh, '99 ', false, 99,'')
chk(pow2(1e2,0)-1, 4, fnh, '99 ', false, 99,'')
chk(pow2(1e2,0)-1, 5, fnh, '99 ', false, 99,'')
chk(pow2(1e2,0)-1, 6, fnh, '99 ', false, 99,'')
chk(pow2(1e2,0)-1, 7, fnh, '99 ', false, 99,'')
chk(pow2(1e2,0)-1, 8, fnh, '99 ', false, 99,'')
chk(pow2(1e2,0)-1, 9, fnh, '99 ', false, 99,'')
chk(pow2(1e3,0)-1, 1, fnh, '1 Ki', true, 1,'Ki')
chk(pow2(1e3,0)-1, 2, fnh, '1000 ', false, 1000,'')
chk(pow2(1e3,0)-1, 3, fnh, '999 ', false, 999,'')
chk(pow2(1e3,0)-1, 4, fnh, '999 ', false, 999,'')
chk(pow2(1e3,0)-1, 5, fnh, '999 ', false, 999,'')
chk(pow2(1e3,0)-1, 6, fnh, '999 ', false, 999,'')
chk(pow2(1e3,0)-1, 7, fnh, '999 ', false, 999,'')
chk(pow2(1e3,0)-1, 8, fnh, '999 ', false, 999,'')
chk(pow2(1e3,0)-1, 9, fnh, '999 ', false, 999,'')
% 1024^1 == pow2(10)
chk(pow2(1e0,10)-1, 1, fnh, '1 Ki', true, 1,'Ki')
chk(pow2(1e0,10)-1, 2, fnh, '1 Ki', true, 1,'Ki')
chk(pow2(1e0,10)-1, 3, fnh, '1020 ', false, 1020,'')
chk(pow2(1e0,10)-1, 4, fnh, '1023 ', false, 1023,'')
chk(pow2(1e0,10)-1, 5, fnh, '1023 ', false, 1023,'')
chk(pow2(1e0,10)-1, 6, fnh, '1023 ', false, 1023,'')
chk(pow2(1e0,10)-1, 7, fnh, '1023 ', false, 1023,'')
chk(pow2(1e0,10)-1, 8, fnh, '1023 ', false, 1023,'')
chk(pow2(1e0,10)-1, 9, fnh, '1023 ', false, 1023,'')
chk(pow2(1e1,10)-1, 1, fnh, '10 Ki', true, 10,'Ki')
chk(pow2(1e1,10)-1, 2, fnh, '10 Ki', true, 10,'Ki')
chk(pow2(1e1,10)-1, 3, fnh, '10 Ki', true, 10,'Ki')
chk(pow2(1e1,10)-1, 4, fnh, '9.999 Ki', true, 9.999,'Ki')
chk(pow2(1e1,10)-1, 5, fnh, '9.999 Ki',  true, 9.9990,'Ki')
chk(pow2(1e1,10)-1, 6, fnh, '9.99902 Ki', true, 9.99902,'Ki')
chk(pow2(1e1,10)-1, 7, fnh, '9.999023 Ki', true, 9.999023,'Ki')
chk(pow2(1e1,10)-1, 8, fnh, '9.9990234 Ki', true, 9.9990234,'Ki')
chk(pow2(1e1,10)-1, 9, fnh, '9.99902344 Ki', true, 9.99902344,'Ki')
chk(pow2(1e2,10)-1, 1, fnh, '100 Ki', true, 100,'Ki')
chk(pow2(1e2,10)-1, 2, fnh, '100 Ki', true, 100,'Ki')
chk(pow2(1e2,10)-1, 3, fnh, '100 Ki', true, 100,'Ki')
chk(pow2(1e2,10)-1, 4, fnh, '100 Ki', true, 100,'Ki')
chk(pow2(1e2,10)-1, 5, fnh, '99.999 Ki', true, 99.999,'Ki')
chk(pow2(1e2,10)-1, 6, fnh, '99.999 Ki',  true, 99.9990,'Ki')
chk(pow2(1e2,10)-1, 7, fnh, '99.99902 Ki', true, 99.99902,'Ki')
chk(pow2(1e2,10)-1, 8, fnh, '99.999023 Ki', true, 99.999023,'Ki')
chk(pow2(1e2,10)-1, 9, fnh, '99.9990234 Ki', true, 99.9990234,'Ki')
chk(pow2(1e3,10)-1, 1, fnh, '1 Mi', true, 1,'Mi')
chk(pow2(1e3,10)-1, 2, fnh, '1000 Ki', true, 1000,'Ki')
chk(pow2(1e3,10)-1, 3, fnh, '1000 Ki', true, 1000,'Ki')
chk(pow2(1e3,10)-1, 4, fnh, '1000 Ki', true, 1000,'Ki')
chk(pow2(1e3,10)-1, 5, fnh, '1000 Ki', true, 1000,'Ki')
chk(pow2(1e3,10)-1, 6, fnh, '999.999 Ki', true, 999.999,'Ki')
chk(pow2(1e3,10)-1, 7, fnh, '999.999 Ki',  true, 999.9990,'Ki')
chk(pow2(1e3,10)-1, 8, fnh, '999.99902 Ki', true, 999.99902,'Ki')
chk(pow2(1e3,10)-1, 9, fnh, '999.999023 Ki', true, 999.999023,'Ki')
% 1024^2 == pow2(20)
chk(pow2(1e0,20)-1, 1, fnh, '1 Mi', true, 1,'Mi')
chk(pow2(1e0,20)-1, 2, fnh, '1 Mi', true, 1,'Mi')
chk(pow2(1e0,20)-1, 3, fnh, '1 Mi', true, 1,'Mi')
chk(pow2(1e0,20)-1, 4, fnh, '1 Mi', true, 1,'Mi')
chk(pow2(1e0,20)-1, 5, fnh, '1 Mi', true, 1,'Mi')
chk(pow2(1e0,20)-1, 6, fnh, '0.999999 Mi', true, 0.999999,'Mi')
chk(pow2(1e0,20)-1, 7, fnh, '1023.999 Ki', true, 1023.999,'Ki')
chk(pow2(1e0,20)-1, 8, fnh, '1023.999 Ki', true, 1023.9990,'Ki')
chk(pow2(1e0,20)-1, 9, fnh, '1023.99902 Ki', true, 1023.99902,'Ki')
chk(pow2(1e1,20)-1, 1, fnh, '10 Mi', true, 10,'Mi')
chk(pow2(1e1,20)-1, 2, fnh, '10 Mi', true, 10,'Mi')
chk(pow2(1e1,20)-1, 3, fnh, '10 Mi', true, 10,'Mi')
chk(pow2(1e1,20)-1, 4, fnh, '10 Mi', true, 10,'Mi')
chk(pow2(1e1,20)-1, 5, fnh, '10 Mi', true, 10,'Mi')
chk(pow2(1e1,20)-1, 6, fnh, '10 Mi', true, 10,'Mi')
chk(pow2(1e1,20)-1, 7, fnh, '9.999999 Mi', true, 9.999999,'Mi')
chk(pow2(1e1,20)-1, 8, fnh, '9.999999 Mi',  true, 9.9999990,'Mi')
chk(pow2(1e1,20)-1, 9, fnh, '9.99999905 Mi', true, 9.99999905,'Mi')
chk(pow2(1e2,20)-1, 1, fnh, '100 Mi', true, 100,'Mi')
chk(pow2(1e2,20)-1, 2, fnh, '100 Mi', true, 100,'Mi')
chk(pow2(1e2,20)-1, 3, fnh, '100 Mi', true, 100,'Mi')
chk(pow2(1e2,20)-1, 4, fnh, '100 Mi', true, 100,'Mi')
chk(pow2(1e2,20)-1, 5, fnh, '100 Mi', true, 100,'Mi')
chk(pow2(1e2,20)-1, 6, fnh, '100 Mi', true, 100,'Mi')
chk(pow2(1e2,20)-1, 7, fnh, '100 Mi', true, 100,'Mi')
chk(pow2(1e2,20)-1, 8, fnh, '99.999999 Mi', true, 99.999999,'Mi')
chk(pow2(1e2,20)-1, 9, fnh, '99.999999 Mi', true, 99.999999,'Mi')
chk(pow2(1e3,20)-1, 1, fnh, '1 Gi', true, 1,'Gi')
chk(pow2(1e3,20)-1, 2, fnh, '1000 Mi', true, 1000,'Mi')
chk(pow2(1e3,20)-1, 3, fnh, '1000 Mi', true, 1000,'Mi')
chk(pow2(1e3,20)-1, 4, fnh, '1000 Mi', true, 1000,'Mi')
chk(pow2(1e3,20)-1, 5, fnh, '1000 Mi', true, 1000,'Mi')
chk(pow2(1e3,20)-1, 6, fnh, '1000 Mi', true, 1000,'Mi')
chk(pow2(1e3,20)-1, 7, fnh, '1000 Mi', true, 1000,'Mi')
chk(pow2(1e3,20)-1, 8, fnh, '1000 Mi', true, 1000,'Mi')
chk(pow2(1e3,20)-1, 9, fnh, '999.999999 Mi', true, 999.999999,'Mi')
% 1024^3 == pow2(30)
chk(pow2(1e0,30)-1, 1, fnh, '1 Gi', true, 1,'Gi')
chk(pow2(1e0,30)-1, 2, fnh, '1 Gi', true, 1,'Gi')
chk(pow2(1e0,30)-1, 3, fnh, '1 Gi', true, 1,'Gi')
chk(pow2(1e0,30)-1, 4, fnh, '1 Gi', true, 1,'Gi')
chk(pow2(1e0,30)-1, 5, fnh, '1 Gi', true, 1,'Gi')
chk(pow2(1e0,30)-1, 6, fnh, '1 Gi', true, 1,'Gi')
chk(pow2(1e0,30)-1, 7, fnh, '1 Gi', true, 1,'Gi')
chk(pow2(1e0,30)-1, 8, fnh, '1 Gi', true, 1,'Gi')
chk(pow2(1e0,30)-1, 9, fnh, '0.999999999 Gi', true, 0.999999999,'Gi')
chk(pow2(1e1,30)-1, 1, fnh, '10 Gi', true, 10,'Gi')
chk(pow2(1e1,30)-1, 2, fnh, '10 Gi', true, 10,'Gi')
chk(pow2(1e1,30)-1, 3, fnh, '10 Gi', true, 10,'Gi')
chk(pow2(1e1,30)-1, 4, fnh, '10 Gi', true, 10,'Gi')
chk(pow2(1e1,30)-1, 5, fnh, '10 Gi', true, 10,'Gi')
chk(pow2(1e1,30)-1, 6, fnh, '10 Gi', true, 10,'Gi')
chk(pow2(1e1,30)-1, 7, fnh, '10 Gi', true, 10,'Gi')
chk(pow2(1e1,30)-1, 8, fnh, '10 Gi', true, 10,'Gi')
chk(pow2(1e1,30)-1, 9, fnh, '10 Gi', true, 10,'Gi')
%
%% Negative %%
%
chk(-1,     fnh, '-1 ', false, -1,'')
chk(-999,   fnh, '-999 ', false, -999,'')
chk(-999,1, fnh, '-1 Ki', true, -1,'Ki')
chk(-999,2, fnh, '-1000 ', false, -1000,'')
chk(-1000,      6, fnh, '-1000 ', false, -1000,'')
chk(-1023,      6, fnh, '-1023 ',  false, -1023,'')
chk(-1023.9,    6, fnh, '-1023.9 ', false, -1023.9,'')
chk(-1023.99,   6, fnh, '-1023.99 ', false, -1023.99,'')
chk(-1023.999,  6, fnh, '-0.999999 Ki', true, -0.999999,'Ki')
chk(-1023.9999, 6, fnh, '-1 Ki', true, -1,'Ki')
chk(-1024,      6, fnh, '-1 Ki', true, -1,'Ki')
%
%% Significant Figures %%
%
chk(pow2(0.999999,10), 1, fnh, '1 Ki', true, 1,'Ki')
chk(pow2(0.999999,10), 2, fnh, '1 Ki', true, 1,'Ki')
chk(pow2(0.999999,10), 3, fnh, '1 Ki', true, 1,'Ki')
chk(pow2(0.999999,10), 4, fnh, '1 Ki', true, 1,'Ki')
chk(pow2(0.999999,10), 5, fnh, '1 Ki', true, 1,'Ki')
chk(pow2(0.999999,10), 6, fnh, '0.999999 Ki', true, 0.999999,'Ki')
chk(pow2(0.999999,10), 7, fnh, '1023.999 ', false, 1023.999,'')
chk(pow2(0.999999,10), 8, fnh, '1023.999 ',  false, 1023.999,'')
chk(pow2(0.999999,10), 9, fnh, '1023.99898 ', false, 1023.99898,'')
%
chk(pow2(0.999999,20), 1, fnh, '1 Mi', true, 1,'Mi')
chk(pow2(0.999999,20), 2, fnh, '1 Mi', true, 1,'Mi')
chk(pow2(0.999999,20), 3, fnh, '1 Mi', true, 1,'Mi')
chk(pow2(0.999999,20), 4, fnh, '1 Mi', true, 1,'Mi')
chk(pow2(0.999999,20), 5, fnh, '1 Mi', true, 1,'Mi')
chk(pow2(0.999999,20), 6, fnh, '0.999999 Mi', true, 0.999999,'Mi')
chk(pow2(0.999999,20), 7, fnh, '1023.999 Ki', true, 1023.999,'Ki')
chk(pow2(0.999999,20), 8, fnh, '1023.999 Ki',  true, 1023.999,'Ki')
chk(pow2(0.999999,20), 9, fnh, '1023.99898 Ki', true, 1023.99898,'Ki')
%
%% Decimal Places %%
%
chk(123.456789, 0, [], 'dp', fnh, '123 ', false, 123,'')
chk(123.456789, 1, [], 'dp', fnh, '123.5 ', false, 123.5,'')
chk(123.456789, 2, [], 'dp', fnh, '123.46 ', false, 123.46,'')
chk(123.456789, 3, [], 'dp', fnh, '123.457 ', false, 123.457,'')
chk(123.456789, 4, [], 'dp', fnh, '123.4568 ', false, 123.4568,'')
chk(123.456789, 5, [], 'dp', fnh, '123.45679 ', false, 123.45679,'')
chk(123.456789, 6, [], 'dp', fnh, '123.456789 ', false, 123.456789,'')
chk(123.456789, 7, [], 'dp', fnh, '123.4567890 ', false, 123.4567890,'')
chk(123.456789, 8, [], 'dp', fnh, '123.45678900 ', false, 123.45678900,'')
chk(123.456789, 9, [], 'dp', fnh, '123.456789000 ', false, 123.456789000,'')
%
chk(pow2(0.999999,10), 0, [], 'dp', fnh, '1 Ki', true, 1,'Ki')
chk(pow2(0.999999,10), 1, [], 'dp', fnh, '1.0 Ki', true, 1,'Ki')
chk(pow2(0.999999,10), 2, [], 'dp', fnh, '1.00 Ki', true, 1,'Ki')
chk(pow2(0.999999,10), 3, [], 'dp', fnh, '1.000 Ki', true, 1,'Ki')
chk(pow2(0.999999,10), 4, [], 'dp', fnh, '1.0000 Ki', true, 1,'Ki')
chk(pow2(0.999999,10), 5, [], 'dp', fnh, '1.00000 Ki', true, 1,'Ki')
chk(pow2(0.999999,10), 6, [], 'dp', fnh, '1023.998976 ', false, 1023.998976,'')
chk(pow2(0.999999,10), 7, [], 'dp', fnh, '1023.9989760 ', false, 1023.998976,'')
chk(pow2(0.999999,10), 8, [], 'dp', fnh, '1023.99897600 ', false, 1023.998976,'')
chk(pow2(0.999999,10), 9, [], 'dp', fnh, '1023.998976000 ', false, 1023.998976,'')
%
chk(1, 3,  '','dp', fnh, '1.000 '  , false, 1,'')
chk(1, 3,'Ki','dp', fnh, '0.001 Ki',  true, 0.001,'Ki')
chk(1, 3,'Mi','dp', fnh, '0.000 Mi',  true, 0,'Mi')
chk(1, 3,'Gi','dp', fnh, '0.000 Gi',  true, 0,'Gi')
chk(1, 3,'Ti','dp', fnh, '0.000 Ti',  true, 0,'Ti')
chk(1, 3,'Pi','dp', fnh, '0.000 Pi',  true, 0,'Pi')
chk(1, 3,'Ei','dp', fnh, '0.000 Ei',  true, 0,'Ei')
chk(1, 3,'Zi','dp', fnh, '0.000 Zi',  true, 0,'Zi')
chk(1, 3,'Yi','dp', fnh, '0.000 Yi',  true, 0,'Yi')
%
%% All Prefixes %%
%
chk(pow2(00), fnh, '1 '  , false, 1,  '')
chk(pow2(10), fnh, '1 Ki',  true, 1,'Ki')
chk(pow2(20), fnh, '1 Mi',  true, 1,'Mi')
chk(pow2(30), fnh, '1 Gi',  true, 1,'Gi')
chk(pow2(40), fnh, '1 Ti',  true, 1,'Ti')
chk(pow2(50), fnh, '1 Pi',  true, 1,'Pi')
chk(pow2(60), fnh, '1 Ei',  true, 1,'Ei')
chk(pow2(70), fnh, '1 Zi',  true, 1,'Zi')
chk(pow2(80), fnh, '1 Yi',  true, 1,'Yi')
%
chk(pow2(9,10), fnh, '9 Ki', true, 9,'Ki')
chk(pow2(8,20), fnh, '8 Mi', true, 8,'Mi')
chk(pow2(7,30), fnh, '7 Gi', true, 7,'Gi')
chk(pow2(6,40), fnh, '6 Ti', true, 6,'Ti')
chk(pow2(5,50), fnh, '5 Pi', true, 5,'Pi')
chk(pow2(4,60), fnh, '4 Ei', true, 4,'Ei')
chk(pow2(3,70), fnh, '3 Zi', true, 3,'Zi')
chk(pow2(2,80), fnh, '2 Yi', true, 2,'Yi')
%
chk(pow2(9.8,10), fnh, '9.8 Ki', true, 9.8,'Ki')
chk(pow2(8.7,20), fnh, '8.7 Mi', true, 8.7,'Mi')
chk(pow2(7.6,30), fnh, '7.6 Gi', true, 7.6,'Gi')
chk(pow2(6.5,40), fnh, '6.5 Ti', true, 6.5,'Ti')
chk(pow2(5.4,50), fnh, '5.4 Pi', true, 5.4,'Pi')
chk(pow2(4.3,60), fnh, '4.3 Ei', true, 4.3,'Ei')
chk(pow2(3.2,70), fnh, '3.2 Zi', true, 3.2,'Zi')
chk(pow2(2.1,80), fnh, '2.1 Yi', true, 2.1,'Yi')
%
chk(pow2(9,10), [], true, fnh, '9 kibi', true, 9,'kibi')
chk(pow2(8,20), [], true, fnh, '8 mebi', true, 8,'mebi')
chk(pow2(7,30), [], true, fnh, '7 gibi', true, 7,'gibi')
chk(pow2(6,40), [], true, fnh, '6 tebi', true, 6,'tebi')
chk(pow2(5,50), [], true, fnh, '5 pebi', true, 5,'pebi')
chk(pow2(4,60), [], true, fnh, '4 exbi', true, 4,'exbi')
chk(pow2(3,70), [], true, fnh, '3 zebi', true, 3,'zebi')
chk(pow2(2,80), [], true, fnh, '2 yobi', true, 2,'yobi')
%
chk(pow2(9.8,10), [], true, fnh, '9.8 kibi', true, 9.8,'kibi')
chk(pow2(8.7,20), [], true, fnh, '8.7 mebi', true, 8.7,'mebi')
chk(pow2(7.6,30), [], true, fnh, '7.6 gibi', true, 7.6,'gibi')
chk(pow2(6.5,40), [], true, fnh, '6.5 tebi', true, 6.5,'tebi')
chk(pow2(5.4,50), [], true, fnh, '5.4 pebi', true, 5.4,'pebi')
chk(pow2(4.3,60), [], true, fnh, '4.3 exbi', true, 4.3,'exbi')
chk(pow2(3.2,70), [], true, fnh, '3.2 zebi', true, 3.2,'zebi')
chk(pow2(2.1,80), [], true, fnh, '2.1 yobi', true, 2.1,'yobi')
%
%% No Prefix EdgeCases %%
%
chk(realmin(), fnh, '2.2251e-308 ')
chk(realmax(), fnh, '1.7977e+308 ')
%
chk(pow2(0.9,        90), 6, fnh,  '921.6 Yi' , true,  921.6 ,'Yi')
chk(pow2(0.99,       90), 6, fnh, '1013.76 Yi', true, 1013.76,'Yi')
chk(pow2(0.999,      90), 6, fnh, '1022.98 Yi', true, 1022.98,'Yi')
chk(pow2(0.9999,     90), 6, fnh, '1023.9 Yi' , true, 1023.9 ,'Yi')
chk(pow2(0.99999,    90), 6, fnh, '1023.99 Yi', true, 1023.99,'Yi')
chk(pow2(0.999999,   90), 6, fnh, '1.23794e+27 ', false, 1.23794e+27,'')
chk(pow2(0.9999999,  90), 6, fnh, '1.23794e+27 ', false, 1.23794e+27,'')
chk(pow2(0.99999999, 90), 6, fnh, '1.23794e+27 ', false, 1.23794e+27,'')
chk(pow2(0.999999999,90), 6, fnh, '1.23794e+27 ', false, 1.23794e+27,'')
chk(pow2(0.9,        90), 6, [], true, fnh, '921.600 Yi', true,  921.6, 'Yi')
chk(pow2(0.99,       90), 6, [], true, fnh, '1013.76 Yi', true, 1013.76,'Yi')
chk(pow2(0.999,      90), 6, [], true, fnh, '1022.98 Yi', true, 1022.98,'Yi')
chk(pow2(0.9999,     90), 6, [], true, fnh, '1023.90 Yi', true, 1023.9, 'Yi')
chk(pow2(0.99999,    90), 6, [], true, fnh, '1023.99 Yi', true, 1023.99,'Yi')
chk(pow2(0.999999,   90), 6, [], true, fnh, '1.23794e+27 ', false, 1.23794e+27,'')
chk(pow2(0.9999999,  90), 6, [], true, fnh, '1.23794e+27 ', false, 1.23794e+27,'')
chk(pow2(0.99999999, 90), 6, [], true, fnh, '1.23794e+27 ', false, 1.23794e+27,'')
chk(pow2(0.999999999,90), 6, [], true, fnh, '1.23794e+27 ', false, 1.23794e+27,'')
%
%% Fixed Prefix Special %%
%
chk(0, [],  '', fnh, '0 '  , false, 0,  '')
chk(0, [],'Ki', fnh, '0 Ki',  true, 0,'Ki')
chk(0, [],'Mi', fnh, '0 Mi',  true, 0,'Mi')
chk(0, [],'Gi', fnh, '0 Gi',  true, 0,'Gi')
chk(0, [],'Ti', fnh, '0 Ti',  true, 0,'Ti')
chk(0, [],'Pi', fnh, '0 Pi',  true, 0,'Pi')
chk(0, [],'Ei', fnh, '0 Ei',  true, 0,'Ei')
chk(0, [],'Zi', fnh, '0 Zi',  true, 0,'Zi')
chk(0, [],'Yi', fnh, '0 Yi',  true, 0,'Yi')
chk(NaN, [],  '', fnh, 'NaN '  , false, NaN,  '')
chk(NaN, [],'Ki', fnh, 'NaN Ki',  true, NaN,'Ki')
chk(NaN, [],'Mi', fnh, 'NaN Mi',  true, NaN,'Mi')
chk(NaN, [],'Gi', fnh, 'NaN Gi',  true, NaN,'Gi')
chk(NaN, [],'Ti', fnh, 'NaN Ti',  true, NaN,'Ti')
chk(NaN, [],'Pi', fnh, 'NaN Pi',  true, NaN,'Pi')
chk(NaN, [],'Ei', fnh, 'NaN Ei',  true, NaN,'Ei')
chk(NaN, [],'Zi', fnh, 'NaN Zi',  true, NaN,'Zi')
chk(NaN, [],'Yi', fnh, 'NaN Yi',  true, NaN,'Yi')
chk(+Inf, [],  '', fnh, 'Inf '  , false, +Inf,  '')
chk(+Inf, [],'Ki', fnh, 'Inf Ki',  true, +Inf,'Ki')
chk(+Inf, [],'Mi', fnh, 'Inf Mi',  true, +Inf,'Mi')
chk(+Inf, [],'Gi', fnh, 'Inf Gi',  true, +Inf,'Gi')
chk(+Inf, [],'Ti', fnh, 'Inf Ti',  true, +Inf,'Ti')
chk(+Inf, [],'Pi', fnh, 'Inf Pi',  true, +Inf,'Pi')
chk(+Inf, [],'Ei', fnh, 'Inf Ei',  true, +Inf,'Ei')
chk(+Inf, [],'Zi', fnh, 'Inf Zi',  true, +Inf,'Zi')
chk(+Inf, [],'Yi', fnh, 'Inf Yi',  true, +Inf,'Yi')
chk(-Inf, [],  '', fnh, '-Inf '  , false, -Inf,''  )
chk(-Inf, [],'Ki', fnh, '-Inf Ki',  true, -Inf,'Ki')
chk(-Inf, [],'Mi', fnh, '-Inf Mi',  true, -Inf,'Mi')
chk(-Inf, [],'Gi', fnh, '-Inf Gi',  true, -Inf,'Gi')
chk(-Inf, [],'Ti', fnh, '-Inf Ti',  true, -Inf,'Ti')
chk(-Inf, [],'Pi', fnh, '-Inf Pi',  true, -Inf,'Pi')
chk(-Inf, [],'Ei', fnh, '-Inf Ei',  true, -Inf,'Ei')
chk(-Inf, [],'Zi', fnh, '-Inf Zi',  true, -Inf,'Zi')
chk(-Inf, [],'Yi', fnh, '-Inf Yi',  true, -Inf,'Yi')
%
%% Fixed Prefix Numeric %%
%
chk(1e-23, [],'', fnh, '0.00000000000000000000001 ', false, 1e-23,'')
%
chk(1023, 1, '', true, fnh, '1000 ', false, 1000,'')
chk(1023, 2, '', true, fnh, '1000 ', false, 1000,'')
chk(1023, 3, '', true, fnh, '1020 ', false, 1020,'')
chk(1023, 4, '', true, fnh, '1023 ', false, 1023,'')
chk(1023, 5, '', true, fnh, '1023.0 ', false, 1023,'')
chk(1023, 6, '', true, fnh, '1023.00 ', false, 1023,'')
chk(1023, 7, '', true, fnh, '1023.000 ', false, 1023,'')
chk(1023, 8, '', true, fnh, '1023.0000 ', false, 1023,'')
chk(1023, 9, '', true, fnh, '1023.00000 ', false, 1023,'')
chk(1023, 1, 'Ki', true, fnh, '1 Ki' , true, 1,'Ki')
chk(1023, 2, 'Ki', true, fnh, '1.0 Ki', true, 1,'Ki')
chk(1023, 3, 'Ki', true, fnh, '0.999 Ki', true, 0.999,'Ki')
chk(1023, 4, 'Ki', true, fnh, '0.9990 Ki', true, 0.9990,'Ki')
chk(1023, 5, 'Ki', true, fnh, '0.99902 Ki', true, 0.99902,'Ki')
chk(1023, 6, 'Ki', true, fnh, '0.999023 Ki', true, 0.999023,'Ki')
chk(1023, 7, 'Ki', true, fnh, '0.9990234 Ki', true, 0.9990234,'Ki')
chk(1023, 8, 'Ki', true, fnh, '0.99902344 Ki', true, 0.99902344,'Ki')
chk(1023, 9, 'Ki', true, fnh, '0.999023438 Ki', true, 0.999023438,'Ki')
chk(1023, 1, 'Mi', true, fnh, '0.001 Mi' , true, 0.001,'Mi')
chk(1023, 2, 'Mi', true, fnh, '0.00098 Mi', true, 0.00098,'Mi')
chk(1023, 3, 'Mi', true, fnh, '0.000976 Mi', true, 0.000976,'Mi')
chk(1023, 4, 'Mi', true, fnh, '0.0009756 Mi', true, 0.0009756,'Mi')
chk(1023, 5, 'Mi', true, fnh, '0.00097561 Mi', true, 0.00097561,'Mi')
chk(1023, 6, 'Mi', true, fnh, '0.000975609 Mi', true, 0.000975609,'Mi')
chk(1023, 7, 'Mi', true, fnh, '0.0009756088 Mi', true, 0.0009756088,'Mi')
chk(1023, 8, 'Mi', true, fnh, '0.00097560883 Mi', true, 0.00097560883,'Mi')
chk(1023, 9, 'Mi', true, fnh, '0.000975608826 Mi', true, 0.000975608826,'Mi')
%
%% Trailing Zeros %%
%
chk(999.999, 1, '', true, fnh, '1000 ', false, 1000,'')
chk(999.999, 2, '', true, fnh, '1000 ', false, 1000,'')
chk(999.999, 3, '', true, fnh, '1000 ', false, 1000,'')
chk(999.999, 4, '', true, fnh, '1000 ', false, 1000,'')
chk(999.999, 5, '', true, fnh, '1000.0 ', false, 1000,'')
chk(999.999, 6, '', true, fnh, '999.999 ', false, 999.999,'')
chk(999.999, 7, '', true, fnh, '999.9990 ', false, 999.999,'')
chk(999.999, 8, '', true, fnh, '999.99900 ', false, 999.999,'')
chk(999.999, 9, '', true, fnh, '999.999000 ', false, 999.999,'')
chk(1023, 1, [], true, fnh, '1 Ki',   true, 1,'Ki')
chk(1023, 2, [], true, fnh, '1.0 Ki', true, 1,'Ki')
chk(1023, 3, [], true, fnh, '1020 ', false, 1020,'')
chk(1023, 4, [], true, fnh, '1023 ',  false, 1023,'')
chk(1023, 5, [], true, fnh, '1023.0 ', false, 1023,'')
chk(1023, 6, [], true, fnh, '1023.00 ', false, 1023,'')
chk(1023, 7, [], true, fnh, '1023.000 ', false, 1023,'')
chk(1023, 8, [], true, fnh, '1023.0000 ', false, 1023,'')
chk(1023, 9, [], true, fnh, '1023.00000 ', false, 1023,'')
%
%% https://physics.nist.gov/cuu/Units/binary.html %%
%
chk(1024,       fnh, '1 Ki')
chk(1048576,    fnh, '1 Mi')
chk(1073741824, fnh, '1 Gi')
%
%% https://rechneronline.de/transfer/binary-prefixes.php %%
%
chk(1.0737e9, 4, true, fnh, '1 gibi')
%
%% https://en.wikipedia.org/wiki/Binary_prefix %%
%
chk(536870912,     fnh, '512 Mi')
chk(500e9,      3, fnh, '466 Gi')
chk(18613795,   3, fnh, '17.8 Mi') % source: 17.7
chk(45708,      3, fnh, '44.6 Ki')
chk(16e3,       3, fnh, '15.6 Ki')
chk(125000,     3, fnh, '122 Ki')
chk(125000000,  3, fnh, '119 Mi')
chk(56000/8,    2, fnh, '6.8 Ki')
chk(3200000000, 2,false,true, fnh, '3.0 Gi')
%
%% http://wolfprojects.altervista.org/articles/binary-and-decimal-prefixes/ %%
%
chk(29131, 3, fnh, '28.4 Ki')
chk(20971520, fnh, '20 Mi')
chk(                     1024, [], true, fnh, '1 kibi')
chk(                  1048576, [], true, fnh, '1 mebi')
chk(               1073741824, [], true, fnh, '1 gibi')
chk(            1099511627776, [], true, fnh, '1 tebi')
chk(         1125899906842624, [], true, fnh, '1 pebi')
chk(      1152921504606846976, [], true, fnh, '1 exbi')
chk(   1180591620717411303424, [], true, fnh, '1 zebi')
chk(1208925819614629174706176, [], true, fnh, '1 yobi')
chk(500e9, [], fnh, '465.66 Gi')
chk(4294967296, fnh, '4 Gi')
chk(20971520, fnh, '20 Mi')
%
%% Display Results %%
%
chk()
%
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%num2bip_test