function num2sip_test()
% Test function for NUM2SIP.
%
% (c) 2011-2024 Stephen Cobeldick
%
% See Also TESTFUN_PREFIX NUM2SIP SIP2NUM NUM2BIP BIP2NUM NUM2RKM RKM2NUM

fnh = @num2sip;
chk = testfun_prefix(fnh);
%
%% Help Examples %%
%
chk(1000, fnh, '1 k')
chk(10000,                 fnh, '10 k')
chk(1e4,                   fnh, '10 k')
chk(10000, 4, true,        fnh, '10 kilo')
chk(10000, 4, false, true, fnh, '10.00 k')
chk(999, 3, fnh, '999 ')
chk(999, 2, fnh, '1 k')
chk(0.5e6,           fnh, '500 k')
chk(0.5e6, [], 'M',  fnh, '0.5 M')
chk(200e6, [], true, fnh, '200 mega') % watt
chk(1234567890, 3, fnh, '1.23 G') % hertz
chk(sip2num('9 T'), fnh, '9 T') % 9 tera
%
%% Basic Edge Cases %%
%
chk(0, fnh, '0 ', false, 0,'')
chk(1, fnh, '1 ', false, 1,'')
chk(NaN, fnh, 'NaN ', false, NaN,'')
chk(+Inf, fnh, 'Inf ', false, +Inf,'')
chk(-Inf, fnh, '-Inf ', false, -Inf,'')
chk(eps(0), fnh, '4.9407e-324 ', false, 4.9407e-324,'')
chk(eps(1), fnh, '222.04 a', true, 222.04,'a')
%
%% Rounding %%
%
% order <= 0
chk(0.999999e-3, 1, [], true, fnh, '1 m', true, 1, 'm')
chk(0.999999e-3, 2, [], true, fnh, '1.0 m', true, 1,'m')
chk(0.999999e-3, 3, [], true, fnh, '1.00 m', true, 1,'m')
chk(0.999999e-3, 4, [], true, fnh, '1.000 m', true, 1,'m')
chk(0.999999e-3, 5, [], true, fnh, '1.0000 m', true, 1,'m')
chk(0.999999e-3, 6, [], true, fnh, '999.999 µ', true, 999.999,'µ')
chk(0.999999e-3, 7, [], true, fnh, '999.9990 µ', true, 999.999,'µ')
chk(0.999999e-3, 8, [], true, fnh, '999.99900 µ', true, 999.999,'µ')
chk(0.999999e-3, 9, [], true, fnh, '999.999000 µ', true, 999.999,'µ')
chk(0.999999e-2, 1, [], true, fnh, '10 m', true, 10,'m')
chk(0.999999e-2, 2, [], true, fnh, '10 m', true, 10,'m')
chk(0.999999e-2, 3, [], true, fnh, '10.0 m', true, 10,'m')
chk(0.999999e-2, 4, [], true, fnh, '10.00 m', true, 10,'m')
chk(0.999999e-2, 5, [], true, fnh, '10.000 m', true, 10,'m')
chk(0.999999e-2, 6, [], true, fnh, '9.99999 m', true, 9.99999,'m')
chk(0.999999e-2, 7, [], true, fnh, '9.999990 m', true, 9.99999,'m')
chk(0.999999e-2, 8, [], true, fnh, '9.9999900 m', true, 9.99999,'m')
chk(0.999999e-2, 9, [], true, fnh, '9.99999000 m', true, 9.99999,'m')
chk(0.999999e-1, 1, [], true, fnh, '100 m', true, 100,'m')
chk(0.999999e-1, 2, [], true, fnh, '100 m', true, 100,'m')
chk(0.999999e-1, 3, [], true, fnh, '100 m', true, 100,'m')
chk(0.999999e-1, 4, [], true, fnh, '100.0 m', true, 100,'m')
chk(0.999999e-1, 5, [], true, fnh, '100.00 m', true, 100,'m')
chk(0.999999e-1, 6, [], true, fnh, '99.9999 m', true, 99.9999,'m')
chk(0.999999e-1, 7, [], true, fnh, '99.99990 m', true, 99.9999,'m')
chk(0.999999e-1, 8, [], true, fnh, '99.999900 m', true, 99.9999,'m')
chk(0.999999e-1, 9, [], true, fnh, '99.9999000 m', true, 99.9999,'m')
chk(0.999999e-0, 1, [], true, fnh, '1 ', false, 1,'')
chk(0.999999e-0, 2, [], true, fnh, '1.0 ', false, 1,'')
chk(0.999999e-0, 3, [], true, fnh, '1.00 ', false, 1,'')
chk(0.999999e-0, 4, [], true, fnh, '1.000 ', false, 1,'')
chk(0.999999e-0, 5, [], true, fnh, '1.0000 ', false, 1,'')
chk(0.999999e-0, 6, [], true, fnh, '999.999 m', true, 999.999,'m')
chk(0.999999e-0, 7, [], true, fnh, '999.9990 m', true, 999.999,'m')
chk(0.999999e-0, 8, [], true, fnh, '999.99900 m', true, 999.999,'m')
chk(0.999999e-0, 9, [], true, fnh, '999.999000 m', true, 999.999,'m')
% order == 0
chk(0.999999e+1, 1, [], true, fnh, '10 ', false, 10,'')
chk(0.999999e+1, 2, [], true, fnh, '10 ', false, 10,'')
chk(0.999999e+1, 3, [], true, fnh, '10.0 ', false, 10,'')
chk(0.999999e+1, 4, [], true, fnh, '10.00 ', false, 10,'')
chk(0.999999e+1, 5, [], true, fnh, '10.000 ', false, 10,'')
chk(0.999999e+1, 6, [], true, fnh, '9.99999 ', false, 9.99999,'')
chk(0.999999e+1, 7, [], true, fnh, '9.999990 ', false, 9.99999,'')
chk(0.999999e+1, 8, [], true, fnh, '9.9999900 ', false, 9.99999,'')
chk(0.999999e+1, 9, [], true, fnh, '9.99999000 ', false, 9.99999,'')
chk(0.999999e+2, 1, [], true, fnh, '100 ', false, 100,'')
chk(0.999999e+2, 2, [], true, fnh, '100 ', false, 100,'')
chk(0.999999e+2, 3, [], true, fnh, '100 ', false, 100,'')
chk(0.999999e+2, 4, [], true, fnh, '100.0 ', false, 100,'')
chk(0.999999e+2, 5, [], true, fnh, '100.00 ', false, 100,'')
chk(0.999999e+2, 6, [], true, fnh, '99.9999 ', false, 99.9999,'')
chk(0.999999e+2, 7, [], true, fnh, '99.99990 ', false, 99.9999,'')
chk(0.999999e+2, 8, [], true, fnh, '99.999900 ', false, 99.9999,'')
chk(0.999999e+2, 9, [], true, fnh, '99.9999000 ', false, 99.9999,'')
% order >= 0
chk(0.999999e+3, 1, [], true, fnh, '1 k', true, 1,'k')
chk(0.999999e+3, 2, [], true, fnh, '1.0 k', true, 1,'k')
chk(0.999999e+3, 3, [], true, fnh, '1.00 k', true, 1,'k')
chk(0.999999e+3, 4, [], true, fnh, '1.000 k', true, 1,'k')
chk(0.999999e+3, 5, [], true, fnh, '1.0000 k', true, 1,'k')
chk(0.999999e+3, 6, [], true, fnh, '999.999 ', false, 999.999,'')
chk(0.999999e+3, 7, [], true, fnh, '999.9990 ', false, 999.999,'')
chk(0.999999e+3, 8, [], true, fnh, '999.99900 ', false, 999.999,'')
chk(0.999999e+3, 9, [], true, fnh, '999.999000 ', false, 999.999,'')
chk(0.999999e+4, 1, [], true, fnh, '10 k', true, 10,'k')
chk(0.999999e+4, 2, [], true, fnh, '10 k', true, 10,'k')
chk(0.999999e+4, 3, [], true, fnh, '10.0 k', true, 10,'k')
chk(0.999999e+4, 4, [], true, fnh, '10.00 k', true, 10,'k')
chk(0.999999e+4, 5, [], true, fnh, '10.000 k', true, 10,'k')
chk(0.999999e+4, 6, [], true, fnh, '9.99999 k', true, 9.99999,'k')
chk(0.999999e+4, 7, [], true, fnh, '9.999990 k', true, 9.99999,'k')
chk(0.999999e+4, 8, [], true, fnh, '9.9999900 k', true, 9.99999,'k')
chk(0.999999e+4, 9, [], true, fnh, '9.99999000 k', true, 9.99999,'k')
chk(0.999999e+5, 1, [], true, fnh, '100 k', true, 100,'k')
chk(0.999999e+5, 2, [], true, fnh, '100 k', true, 100,'k')
chk(0.999999e+5, 3, [], true, fnh, '100 k', true, 100,'k')
chk(0.999999e+5, 4, [], true, fnh, '100.0 k', true, 100,'k')
chk(0.999999e+5, 5, [], true, fnh, '100.00 k', true, 100,'k')
chk(0.999999e+5, 6, [], true, fnh, '99.9999 k', true, 99.9999,'k')
chk(0.999999e+5, 7, [], true, fnh, '99.99990 k', true, 99.9999,'k')
chk(0.999999e+5, 8, [], true, fnh, '99.999900 k', true, 99.9999,'k')
chk(0.999999e+5, 9, [], true, fnh, '99.9999000 k', true, 99.9999,'k')
chk(0.999999e+6, 1, [], true, fnh, '1 M', true, 1,'M')
chk(0.999999e+6, 2, [], true, fnh, '1.0 M', true, 1,'M')
chk(0.999999e+6, 3, [], true, fnh, '1.00 M', true, 1,'M')
chk(0.999999e+6, 4, [], true, fnh, '1.000 M', true, 1,'M')
chk(0.999999e+6, 5, [], true, fnh, '1.0000 M', true, 1,'M')
chk(0.999999e+6, 6, [], true, fnh, '999.999 k', true, 999.999,'k')
chk(0.999999e+6, 7, [], true, fnh, '999.9990 k', true, 999.999,'k')
chk(0.999999e+6, 8, [], true, fnh, '999.99900 k', true, 999.999,'k')
chk(0.999999e+6, 9, [], true, fnh, '999.999000 k', true, 999.999,'k')
%
%% One Less Than %%
%
% 1000^0 == 1e0
chk(1e0-1, 1, fnh, '0 ', false, 0,'')
chk(1e0-1, 2, fnh, '0 ', false, 0,'')
chk(1e0-1, 3, fnh, '0 ', false, 0,'')
chk(1e0-1, 4, fnh, '0 ', false, 0,'')
chk(1e0-1, 5, fnh, '0 ', false, 0,'')
chk(1e0-1, 6, fnh, '0 ', false, 0,'')
chk(1e0-1, 7, fnh, '0 ', false, 0,'')
chk(1e0-1, 8, fnh, '0 ', false, 0,'')
chk(1e0-1, 9, fnh, '0 ', false, 0,'')
chk(1e1-1, 1, fnh, '9 ', false, 9,'')
chk(1e1-1, 2, fnh, '9 ', false, 9,'')
chk(1e1-1, 3, fnh, '9 ', false, 9,'')
chk(1e1-1, 4, fnh, '9 ', false, 9,'')
chk(1e1-1, 5, fnh, '9 ', false, 9,'')
chk(1e1-1, 6, fnh, '9 ', false, 9,'')
chk(1e1-1, 7, fnh, '9 ', false, 9,'')
chk(1e1-1, 8, fnh, '9 ', false, 9,'')
chk(1e1-1, 9, fnh, '9 ', false, 9,'')
chk(1e2-1, 1, fnh, '100 ', false, 100,'')
chk(1e2-1, 2, fnh, '99 ', false, 99,'')
chk(1e2-1, 3, fnh, '99 ', false, 99,'')
chk(1e2-1, 4, fnh, '99 ', false, 99,'')
chk(1e2-1, 5, fnh, '99 ', false, 99,'')
chk(1e2-1, 6, fnh, '99 ', false, 99,'')
chk(1e2-1, 7, fnh, '99 ', false, 99,'')
chk(1e2-1, 8, fnh, '99 ', false, 99,'')
chk(1e2-1, 9, fnh, '99 ', false, 99,'')
% 1000^1 == 1e3
chk(1e3-1, 1, fnh, '1 k', true, 1,'k')
chk(1e3-1, 2, fnh, '1 k', true, 1,'k')
chk(1e3-1, 3, fnh, '999 ', false, 999,'')
chk(1e3-1, 4, fnh, '999 ', false, 999,'')
chk(1e3-1, 5, fnh, '999 ', false, 999,'')
chk(1e3-1, 6, fnh, '999 ', false, 999,'')
chk(1e3-1, 7, fnh, '999 ', false, 999,'')
chk(1e3-1, 8, fnh, '999 ', false, 999,'')
chk(1e3-1, 9, fnh, '999 ', false, 999,'')
chk(1e4-1, 1, fnh, '10 k', true, 10,'k')
chk(1e4-1, 2, fnh, '10 k', true, 10,'k')
chk(1e4-1, 3, fnh, '10 k', true, 10,'k')
chk(1e4-1, 4, fnh, '9.999 k', true, 9.999,'k')
chk(1e4-1, 5, fnh, '9.999 k', true, 9.999,'k')
chk(1e4-1, 6, fnh, '9.999 k', true, 9.999,'k')
chk(1e4-1, 7, fnh, '9.999 k', true, 9.999,'k')
chk(1e4-1, 8, fnh, '9.999 k', true, 9.999,'k')
chk(1e4-1, 9, fnh, '9.999 k', true, 9.999,'k')
chk(1e5-1, 1, fnh, '100 k', true, 100,'k')
chk(1e5-1, 2, fnh, '100 k', true, 100,'k')
chk(1e5-1, 3, fnh, '100 k', true, 100,'k')
chk(1e5-1, 4, fnh, '100 k', true, 100,'k')
chk(1e5-1, 5, fnh, '99.999 k', true, 99.999,'k')
chk(1e5-1, 6, fnh, '99.999 k', true, 99.999,'k')
chk(1e5-1, 7, fnh, '99.999 k', true, 99.999,'k')
chk(1e5-1, 8, fnh, '99.999 k', true, 99.999,'k')
chk(1e5-1, 9, fnh, '99.999 k', true, 99.999,'k')
% 1000^2 == 1e6
chk(1e6-1, 1, fnh, '1 M', true, 1,'M')
chk(1e6-1, 2, fnh, '1 M', true, 1,'M')
chk(1e6-1, 3, fnh, '1 M', true, 1,'M')
chk(1e6-1, 4, fnh, '1 M', true, 1,'M')
chk(1e6-1, 5, fnh, '1 M', true, 1,'M')
chk(1e6-1, 6, fnh, '999.999 k', true, 999.999,'k')
chk(1e6-1, 7, fnh, '999.999 k', true, 999.999,'k')
chk(1e6-1, 8, fnh, '999.999 k', true, 999.999,'k')
chk(1e6-1, 9, fnh, '999.999 k', true, 999.999,'k')
chk(1e7-1, 1, fnh, '10 M', true, 10,'M')
chk(1e7-1, 2, fnh, '10 M', true, 10,'M')
chk(1e7-1, 3, fnh, '10 M', true, 10,'M')
chk(1e7-1, 4, fnh, '10 M', true, 10,'M')
chk(1e7-1, 5, fnh, '10 M', true, 10,'M')
chk(1e7-1, 6, fnh, '10 M', true, 10,'M')
chk(1e7-1, 7, fnh, '9.999999 M', true, 9.999999,'M')
chk(1e7-1, 8, fnh, '9.999999 M', true, 9.999999,'M')
chk(1e7-1, 9, fnh, '9.999999 M', true, 9.999999,'M')
chk(1e8-1, 1, fnh, '100 M', true, 100,'M')
chk(1e8-1, 2, fnh, '100 M', true, 100,'M')
chk(1e8-1, 3, fnh, '100 M', true, 100,'M')
chk(1e8-1, 4, fnh, '100 M', true, 100,'M')
chk(1e8-1, 5, fnh, '100 M', true, 100,'M')
chk(1e8-1, 6, fnh, '100 M', true, 100,'M')
chk(1e8-1, 7, fnh, '100 M', true, 100,'M')
chk(1e8-1, 8, fnh, '99.999999 M', true, 99.999999,'M')
chk(1e8-1, 9, fnh, '99.999999 M', true, 99.999999,'M')
% 1000^3 == 1e9
chk(1e9-1, 1, fnh, '1 G', true, 1,'G')
chk(1e9-1, 2, fnh, '1 G', true, 1,'G')
chk(1e9-1, 3, fnh, '1 G', true, 1,'G')
chk(1e9-1, 4, fnh, '1 G', true, 1,'G')
chk(1e9-1, 5, fnh, '1 G', true, 1,'G')
chk(1e9-1, 6, fnh, '1 G', true, 1,'G')
chk(1e9-1, 7, fnh, '1 G', true, 1,'G')
chk(1e9-1, 8, fnh, '1 G', true, 1,'G')
chk(1e9-1, 9, fnh, '999.999999 M', true, 999.999999,'M')
chk(1e10-1, 1, fnh, '10 G', true, 10,'G')
chk(1e10-1, 2, fnh, '10 G', true, 10,'G')
chk(1e10-1, 3, fnh, '10 G', true, 10,'G')
chk(1e10-1, 4, fnh, '10 G', true, 10,'G')
chk(1e10-1, 5, fnh, '10 G', true, 10,'G')
chk(1e10-1, 6, fnh, '10 G', true, 10,'G')
chk(1e10-1, 7, fnh, '10 G', true, 10,'G')
chk(1e10-1, 8, fnh, '10 G', true, 10,'G')
chk(1e10-1, 9, fnh, '10 G', true, 10,'G')
%
%% Negative %%
%
chk(-1,      fnh, '-1 ', false, -1,'')
chk(-999,    fnh, '-999 ',false,  -999,'')
chk(-999, 1, fnh, '-1 k', true, -1,'k')
chk(-999, 2, fnh, '-1 k', true, -1,'k')
chk(-999,        6, fnh, '-999 ', false, -999,'')
chk(-999.9,      6, fnh, '-999.9 ', false, -999.9,'')
chk(-999.99,     6, fnh, '-999.99 ', false, -999.99,'')
chk(-999.999,    6, fnh, '-999.999 ', false, -999.999,'')
chk(-999.9999,   6, fnh, '-1 k', true, -1,'k')
chk(-999.99999,  6, fnh, '-1 k', true, -1,'k')
chk(-999.999999, 6, fnh, '-1 k', true, -1,'k')
chk(-1e-6, fnh, '-1 µ', true, -1,'µ')
chk(-1e-3, fnh, '-1 m', true, -1,'m')
chk(-1e+3, fnh, '-1 k', true, -1,'k')
chk(-1e+6, fnh, '-1 M', true, -1,'M')
%
%% Significant Figures %%
%
chk(999.999, 1, fnh, '1 k', true, 1,'k')
chk(999.999, 2, fnh, '1 k', true, 1,'k')
chk(999.999, 3, fnh, '1 k', true, 1,'k')
chk(999.999, 4, fnh, '1 k', true, 1,'k')
chk(999.999, 5, fnh, '1 k', true, 1,'k')
chk(999.999, 6, fnh, '999.999 ', false, 999.999,'')
chk(999.999, 7, fnh, '999.999 ', false, 999.999,'')
chk(999.999, 8, fnh, '999.999 ', false, 999.999,'')
chk(999.999, 9, fnh, '999.999 ', false, 999.999,'')
%
chk(999999, 1, fnh, '1 M', true, 1,'M')
chk(999999, 2, fnh, '1 M', true, 1,'M')
chk(999999, 3, fnh, '1 M', true, 1,'M')
chk(999999, 4, fnh, '1 M', true, 1,'M')
chk(999999, 5, fnh, '1 M', true, 1,'M')
chk(999999, 6, fnh, '999.999 k', true, 999.999,'k')
chk(999999, 7, fnh, '999.999 k', true, 999.999,'k')
chk(999999, 8, fnh, '999.999 k', true, 999.999,'k')
chk(999999, 9, fnh, '999.999 k', true, 999.999,'k')
%
%% Decimal Places %%
%
chk(123.456789, 0, [], 'dp', fnh, '123 ', false, 123,'')
chk(123.456789, 1, [], 'dp', fnh, '123.5 ', false, 123.5,'')
chk(123.456789, 2, [], 'dp', fnh, '123.46 ', false, 123.46,'')
chk(123.456789, 3, [], 'dp', fnh, '123.457 ', false, 123.457,'')
chk(123.456789, 4, [], 'dp', fnh, '123.4568 ', false, 123.4568,'')
chk(123.456789, 5, [], 'dp', fnh, '123.45679 ', false, 123.45679,'')
chk(123.456789, 6, [], 'dp', fnh, '123.456789 ', false, 123.456789,'')
chk(123.456789, 7, [], 'dp', fnh, '123.4567890 ', false, 123.4567890,'')
chk(123.456789, 8, [], 'dp', fnh, '123.45678900 ', false, 123.45678900,'')
chk(123.456789, 9, [], 'dp', fnh, '123.456789000 ', false, 123.456789000,'')
%
chk(999.999, 0, [], 'dp', fnh, '1 k', true, 1,'k')
chk(999.999, 1, [], 'dp', fnh, '1.0 k', true, 1,'k')
chk(999.999, 2, [], 'dp', fnh, '1.00 k', true, 1,'k')
chk(999.999, 3, [], 'dp', fnh, '1.000 k', true, 1,'k')
chk(999.999, 4, [], 'dp', fnh, '1.0000 k', true, 1,'k')
chk(999.999, 5, [], 'dp', fnh, '1.00000 k', true, 1,'k')
chk(999.999, 6, [], 'dp', fnh, '999.999000 ', false, 999.999,'')
chk(999.999, 7, [], 'dp', fnh, '999.9990000 ', false, 999.999,'')
chk(999.999, 8, [], 'dp', fnh, '999.99900000 ', false, 999.999,'')
chk(999.999, 9, [], 'dp', fnh, '999.999000000 ', false, 999.999,'')
%
chk(1, 3,'p','dp', fnh, '1000000000000.000 p', true, 1e12,'p') % limit of DOUBLE
chk(1, 3,'n','dp', fnh, '1000000000.000 n', true, 1e9,'n')
chk(1, 3,'µ','dp', fnh, '1000000.000 µ', true, 1e6,'µ')
chk(1, 3,'m','dp', fnh, '1000.000 m', true, 1e3,'m')
chk(1, 3, '','dp', fnh, '1.000 ',  false, 1e0,'')
chk(1, 3,'k','dp', fnh, '0.001 k', true, 0.001,'k')
chk(1, 3,'M','dp', fnh, '0.000 M', true, 0,'M')
chk(1, 3,'G','dp', fnh, '0.000 G', true, 0,'G')
chk(1, 3,'T','dp', fnh, '0.000 T', true, 0,'T')
chk(1, 3,'P','dp', fnh, '0.000 P', true, 0,'P')
chk(1, 3,'E','dp', fnh, '0.000 E', true, 0,'E')
chk(1, 3,'Z','dp', fnh, '0.000 Z', true, 0,'Z')
chk(1, 3,'Y','dp', fnh, '0.000 Y', true, 0,'Y')
chk(1, 3,'R','dp', fnh, '0.000 R', true, 0,'R')
chk(1, 3,'Q','dp', fnh, '0.000 Q', true, 0,'Q')
%
%% All Prefixes %%
%
chk(1e-30, fnh, '1 q',  true, 1,'q')
chk(1e-27, fnh, '1 r',  true, 1,'r')
chk(1e-24, fnh, '1 y',  true, 1,'y')
chk(1e-21, fnh, '1 z',  true, 1,'z')
chk(1e-18, fnh, '1 a',  true, 1,'a')
chk(1e-15, fnh, '1 f',  true, 1,'f')
chk(1e-12, fnh, '1 p',  true, 1,'p')
chk(1e-9 , fnh, '1 n',  true, 1,'n')
chk(1e-6 , fnh, '1 µ',  true, 1,'µ')
chk(1e-3 , fnh, '1 m',  true, 1,'m')
chk(1e0  , fnh, '1 ' , false, 1, '')
chk(1e+3 , fnh, '1 k',  true, 1,'k')
chk(1e+6 , fnh, '1 M',  true, 1,'M')
chk(1e+9 , fnh, '1 G',  true, 1,'G')
chk(1e+12, fnh, '1 T',  true, 1,'T')
chk(1e+15, fnh, '1 P',  true, 1,'P')
chk(1e+18, fnh, '1 E',  true, 1,'E')
chk(1e+21, fnh, '1 Z',  true, 1,'Z')
chk(1e+24, fnh, '1 Y',  true, 1,'Y')
chk(1e+27, fnh, '1 R',  true, 1,'R')
chk(1e+30, fnh, '1 Q',  true, 1,'Q')
%
chk(1.2e-30, fnh, '1.2 q',  true, 1.2,'q')
chk(9.1e-27, fnh, '9.1 r',  true, 9.1,'r')
chk(8.9e-24, fnh, '8.9 y',  true, 8.9,'y')
chk(7.8e-21, fnh, '7.8 z',  true, 7.8,'z')
chk(6.7e-18, fnh, '6.7 a',  true, 6.7,'a')
chk(5.6e-15, fnh, '5.6 f',  true, 5.6,'f')
chk(4.5e-12, fnh, '4.5 p',  true, 4.5,'p')
chk(3.4e-9 , fnh, '3.4 n',  true, 3.4,'n')
chk(2.3e-6 , fnh, '2.3 µ',  true, 2.3,'µ')
chk(1.2e-3 , fnh, '1.2 m',  true, 1.2,'m')
chk(9.1e0  , fnh, '9.1 ' , false, 9.1, '')
chk(1.2e+3 , fnh, '1.2 k',  true, 1.2,'k')
chk(2.3e+6 , fnh, '2.3 M',  true, 2.3,'M')
chk(3.4e+9 , fnh, '3.4 G',  true, 3.4,'G')
chk(4.5e+12, fnh, '4.5 T',  true, 4.5,'T')
chk(5.6e+15, fnh, '5.6 P',  true, 5.6,'P')
chk(6.7e+18, fnh, '6.7 E',  true, 6.7,'E')
chk(7.8e+21, fnh, '7.8 Z',  true, 7.8,'Z')
chk(8.9e+24, fnh, '8.9 Y',  true, 8.9,'Y')
chk(9.1e+27, fnh, '9.1 R',  true, 9.1,'R')
chk(1.2e+30, fnh, '1.2 Q',  true, 1.2,'Q')
%
chk(1e-30, [], true, fnh, '1 quecto',  true, 1,'quecto')
chk(1e-27, [], true, fnh, '1 ronto' ,  true, 1, 'ronto')
chk(1e-24, [], true, fnh, '1 yocto' ,  true, 1, 'yocto')
chk(1e-21, [], true, fnh, '1 zepto' ,  true, 1, 'zepto')
chk(1e-18, [], true, fnh, '1 atto'  ,  true, 1,  'atto')
chk(1e-15, [], true, fnh, '1 femto' ,  true, 1, 'femto')
chk(1e-12, [], true, fnh, '1 pico'  ,  true, 1,  'pico')
chk(1e-9 , [], true, fnh, '1 nano'  ,  true, 1,  'nano')
chk(1e-6 , [], true, fnh, '1 micro' ,  true, 1, 'micro')
chk(1e-3 , [], true, fnh, '1 milli' ,  true, 1, 'milli')
chk(1e-0 , [], true, fnh, '1 '      , false, 1,      '')
chk(1e+0 , [], true, fnh, '1 '      , false, 1,      '')
chk(1e+3 , [], true, fnh, '1 kilo'  ,  true, 1,  'kilo')
chk(1e+6 , [], true, fnh, '1 mega'  ,  true, 1,  'mega')
chk(1e+9 , [], true, fnh, '1 giga'  ,  true, 1,  'giga')
chk(1e+12, [], true, fnh, '1 tera'  ,  true, 1,  'tera')
chk(1e+15, [], true, fnh, '1 peta'  ,  true, 1,  'peta')
chk(1e+18, [], true, fnh, '1 exa'   ,  true, 1,   'exa')
chk(1e+21, [], true, fnh, '1 zetta' ,  true, 1, 'zetta')
chk(1e+24, [], true, fnh, '1 yotta' ,  true, 1, 'yotta')
chk(1e+27, [], true, fnh, '1 ronna' ,  true, 1, 'ronna')
chk(1e+30, [], true, fnh, '1 quetta',  true, 1,'quetta')
%
chk(8.9e-30, [], true, fnh, '8.9 quecto',  true, 8.9,'quecto')
chk(9.1e-27, [], true, fnh, '9.1 ronto' ,  true, 9.1, 'ronto')
chk(1.2e-24, [], true, fnh, '1.2 yocto' ,  true, 1.2, 'yocto')
chk(2.3e-21, [], true, fnh, '2.3 zepto' ,  true, 2.3, 'zepto')
chk(3.4e-18, [], true, fnh, '3.4 atto'  ,  true, 3.4,  'atto')
chk(4.5e-15, [], true, fnh, '4.5 femto' ,  true, 4.5, 'femto')
chk(5.6e-12, [], true, fnh, '5.6 pico'  ,  true, 5.6,  'pico')
chk(6.7e-9 , [], true, fnh, '6.7 nano'  ,  true, 6.7,  'nano')
chk(7.8e-6 , [], true, fnh, '7.8 micro' ,  true, 7.8, 'micro')
chk(8.9e-3 , [], true, fnh, '8.9 milli' ,  true, 8.9, 'milli')
chk(9.1e0  , [], true, fnh, '9.1 '      , false, 9.1,      '')
chk(8.9e+3 , [], true, fnh, '8.9 kilo'  ,  true, 8.9,  'kilo')
chk(7.8e+6 , [], true, fnh, '7.8 mega'  ,  true, 7.8,  'mega')
chk(6.7e+9 , [], true, fnh, '6.7 giga'  ,  true, 6.7,  'giga')
chk(5.6e+12, [], true, fnh, '5.6 tera'  ,  true, 5.6,  'tera')
chk(4.5e+15, [], true, fnh, '4.5 peta'  ,  true, 4.5,  'peta')
chk(3.4e+18, [], true, fnh, '3.4 exa'   ,  true, 3.4,   'exa')
chk(2.3e+21, [], true, fnh, '2.3 zetta' ,  true, 2.3, 'zetta')
chk(1.2e+24, [], true, fnh, '1.2 yotta' ,  true, 1.2, 'yotta')
chk(9.1e+27, [], true, fnh, '9.1 ronna' ,  true, 9.1, 'ronna')
chk(8.9e+30, [], true, fnh, '8.9 quetta',  true, 8.9,'quetta')
%
%% No Prefix EdgeCases %%
%
chk(realmin(), fnh, '2.2251e-308 ', false, 2.2251e-308,'')
chk(realmax(), fnh, '1.7977e+308 ', false, 1.7977e+308,'')
%
chk(0.9e33,           6, fnh, '900 Q', true, 900,'Q')
chk(0.99e33,          6, fnh, '990 Q', true, 990,'Q')
chk(0.999e33,         6, fnh, '999 Q', true, 999,'Q')
chk(0.9999e33,        6, fnh, '999.9 Q', true, 999.9,'Q')
chk(0.99999e33,       6, fnh, '999.99 Q', true, 999.99,'Q')
chk(0.999999e33,      6, fnh, '999.999 Q', true, 999.999,'Q')
chk(0.9999999e33,     6, fnh, '1e+33 ', false, 1e33,'')
chk(0.99999999e33,    6, fnh, '1e+33 ', false, 1e33,'')
chk(0.999999999e33,   6, fnh, '1e+33 ', false, 1e33,'')
chk(0.9999999999e33,  6, fnh, '1e+33 ', false, 1e33,'')
chk(0.99999999999e33, 6, fnh, '1e+33 ', false, 1e33,'')
chk(0.9999999e33, 1, [], true, fnh, '1e+33 ', false, 1e33,'')
chk(0.9999999e33, 2, [], true, fnh, '1.0e+33 ', false, 1e33,'')
chk(0.9999999e33, 3, [], true, fnh, '1.00e+33 ', false, 1e33,'')
chk(0.9999999e33, 4, [], true, fnh, '1.000e+33 ', false, 1e33,'')
chk(0.9999999e33, 5, [], true, fnh, '1.0000e+33 ', false, 1e33,'')
chk(0.9999999e33, 6, [], true, fnh, '1.00000e+33 ', false, 1e33,'')
chk(0.9999999e33, 7, [], true, fnh, '999.9999 Q', true, 999.9999,'Q')
chk(0.9999999e33, 8, [], true, fnh, '999.99990 Q', true, 999.9999,'Q')
chk(0.9999999e33, 9, [], true, fnh, '999.999900 Q', true, 999.9999,'Q')
%
chk(0.9e-30,          6, fnh, '9e-31 ', false, 9e-31,'')
chk(0.99e-30,         6, fnh, '9.9e-31 ', false, 9.9e-31,'')
chk(0.999e-30,        6, fnh, '9.99e-31 ', false, 9.99e-31,'')
chk(0.9999e-30,       6, fnh, '9.999e-31 ', false, 9.999e-31,'')
chk(0.99999e-30,      6, fnh, '9.9999e-31 ', false, 9.9999e-31,'')
chk(0.999999e-30,     6, fnh, '9.99999e-31 ', false, 9.99999e-31,'')
chk(0.9999999e-30,    6, fnh, '1 q', true, 1,'q')
chk(0.99999999e-30,   6, fnh, '1 q', true, 1,'q')
chk(0.999999999e-30,  6, fnh, '1 q', true, 1,'q')
chk(0.9999999999e-30, 6, fnh, '1 q', true, 1,'q')
chk(0.9e-30,          6, [], true, fnh, '9.00000e-31 ', false, 9e-31,'')
chk(0.99e-30,         6, [], true, fnh, '9.90000e-31 ', false, 9.9e-31,'')
chk(0.999e-30,        6, [], true, fnh, '9.99000e-31 ', false, 9.99e-31,'')
chk(0.9999e-30,       6, [], true, fnh, '9.99900e-31 ', false, 9.999e-31,'')
chk(0.99999e-30,      6, [], true, fnh, '9.99990e-31 ', false, 9.9999e-31,'')
chk(0.999999e-30,     6, [], true, fnh, '9.99999e-31 ', false, 9.99999e-31,'')
chk(0.9999999e-30,    6, [], true, fnh, '1.00000 q', true, 1,'q')
chk(0.99999999e-30,   6, [], true, fnh, '1.00000 q', true, 1,'q')
chk(0.999999999e-30,  6, [], true, fnh, '1.00000 q', true, 1,'q')
chk(0.9999999999e-30, 6, [], true, fnh, '1.00000 q', true, 1,'q')
%
%% Fixed Prefix Special %%
%
chk(0, [],'q', fnh, '0 q',  true, 0,'q')
chk(0, [],'r', fnh, '0 r',  true, 0,'r')
chk(0, [],'y', fnh, '0 y',  true, 0,'y')
chk(0, [],'z', fnh, '0 z',  true, 0,'z')
chk(0, [],'a', fnh, '0 a',  true, 0,'a')
chk(0, [],'f', fnh, '0 f',  true, 0,'f')
chk(0, [],'p', fnh, '0 p',  true, 0,'p')
chk(0, [],'n', fnh, '0 n',  true, 0,'n')
chk(0, [],'u', fnh, '0 µ',  true, 0,'µ')
chk(0, [],'m', fnh, '0 m',  true, 0,'m')
chk(0, [], '', fnh, '0 ' , false, 0, '')
chk(0, [],'k', fnh, '0 k',  true, 0,'k')
chk(0, [],'M', fnh, '0 M',  true, 0,'M')
chk(0, [],'G', fnh, '0 G',  true, 0,'G')
chk(0, [],'T', fnh, '0 T',  true, 0,'T')
chk(0, [],'P', fnh, '0 P',  true, 0,'P')
chk(0, [],'E', fnh, '0 E',  true, 0,'E')
chk(0, [],'Z', fnh, '0 Z',  true, 0,'Z')
chk(0, [],'Y', fnh, '0 Y',  true, 0,'Y')
chk(0, [],'R', fnh, '0 R',  true, 0,'R')
chk(0, [],'Q', fnh, '0 Q',  true, 0,'Q')
chk(NaN, [],'q', fnh, 'NaN q',  true, NaN,'q')
chk(NaN, [],'r', fnh, 'NaN r',  true, NaN,'r')
chk(NaN, [],'y', fnh, 'NaN y',  true, NaN,'y')
chk(NaN, [],'z', fnh, 'NaN z',  true, NaN,'z')
chk(NaN, [],'a', fnh, 'NaN a',  true, NaN,'a')
chk(NaN, [],'f', fnh, 'NaN f',  true, NaN,'f')
chk(NaN, [],'p', fnh, 'NaN p',  true, NaN,'p')
chk(NaN, [],'n', fnh, 'NaN n',  true, NaN,'n')
chk(NaN, [],'u', fnh, 'NaN µ',  true, NaN,'µ')
chk(NaN, [],'m', fnh, 'NaN m',  true, NaN,'m')
chk(NaN, [], '', fnh, 'NaN ' , false, NaN, '')
chk(NaN, [],'k', fnh, 'NaN k',  true, NaN,'k')
chk(NaN, [],'M', fnh, 'NaN M',  true, NaN,'M')
chk(NaN, [],'G', fnh, 'NaN G',  true, NaN,'G')
chk(NaN, [],'T', fnh, 'NaN T',  true, NaN,'T')
chk(NaN, [],'P', fnh, 'NaN P',  true, NaN,'P')
chk(NaN, [],'E', fnh, 'NaN E',  true, NaN,'E')
chk(NaN, [],'Z', fnh, 'NaN Z',  true, NaN,'Z')
chk(NaN, [],'Y', fnh, 'NaN Y',  true, NaN,'Y')
chk(NaN, [],'R', fnh, 'NaN R',  true, NaN,'R')
chk(NaN, [],'Q', fnh, 'NaN Q',  true, NaN,'Q')
chk(+Inf, [],'q', fnh, 'Inf q',  true, +Inf,'q')
chk(+Inf, [],'r', fnh, 'Inf r',  true, +Inf,'r')
chk(+Inf, [],'y', fnh, 'Inf y',  true, +Inf,'y')
chk(+Inf, [],'z', fnh, 'Inf z',  true, +Inf,'z')
chk(+Inf, [],'a', fnh, 'Inf a',  true, +Inf,'a')
chk(+Inf, [],'f', fnh, 'Inf f',  true, +Inf,'f')
chk(+Inf, [],'p', fnh, 'Inf p',  true, +Inf,'p')
chk(+Inf, [],'n', fnh, 'Inf n',  true, +Inf,'n')
chk(+Inf, [],'u', fnh, 'Inf µ',  true, +Inf,'µ')
chk(+Inf, [],'m', fnh, 'Inf m',  true, +Inf,'m')
chk(+Inf, [], '', fnh, 'Inf ' , false, +Inf, '')
chk(+Inf, [],'k', fnh, 'Inf k',  true, +Inf,'k')
chk(+Inf, [],'M', fnh, 'Inf M',  true, +Inf,'M')
chk(+Inf, [],'G', fnh, 'Inf G',  true, +Inf,'G')
chk(+Inf, [],'T', fnh, 'Inf T',  true, +Inf,'T')
chk(+Inf, [],'P', fnh, 'Inf P',  true, +Inf,'P')
chk(+Inf, [],'E', fnh, 'Inf E',  true, +Inf,'E')
chk(+Inf, [],'Z', fnh, 'Inf Z',  true, +Inf,'Z')
chk(+Inf, [],'Y', fnh, 'Inf Y',  true, +Inf,'Y')
chk(+Inf, [],'R', fnh, 'Inf R',  true, +Inf,'R')
chk(+Inf, [],'Q', fnh, 'Inf Q',  true, +Inf,'Q')
chk(-Inf, [],'q', fnh, '-Inf q',  true, -Inf,'q')
chk(-Inf, [],'r', fnh, '-Inf r',  true, -Inf,'r')
chk(-Inf, [],'y', fnh, '-Inf y',  true, -Inf,'y')
chk(-Inf, [],'z', fnh, '-Inf z',  true, -Inf,'z')
chk(-Inf, [],'a', fnh, '-Inf a',  true, -Inf,'a')
chk(-Inf, [],'f', fnh, '-Inf f',  true, -Inf,'f')
chk(-Inf, [],'p', fnh, '-Inf p',  true, -Inf,'p')
chk(-Inf, [],'n', fnh, '-Inf n',  true, -Inf,'n')
chk(-Inf, [],'u', fnh, '-Inf µ',  true, -Inf,'µ')
chk(-Inf, [],'m', fnh, '-Inf m',  true, -Inf,'m')
chk(-Inf, [], '', fnh, '-Inf ' , false, -Inf, '')
chk(-Inf, [],'k', fnh, '-Inf k',  true, -Inf,'k')
chk(-Inf, [],'M', fnh, '-Inf M',  true, -Inf,'M')
chk(-Inf, [],'G', fnh, '-Inf G',  true, -Inf,'G')
chk(-Inf, [],'T', fnh, '-Inf T',  true, -Inf,'T')
chk(-Inf, [],'P', fnh, '-Inf P',  true, -Inf,'P')
chk(-Inf, [],'E', fnh, '-Inf E',  true, -Inf,'E')
chk(-Inf, [],'Z', fnh, '-Inf Z',  true, -Inf,'Z')
chk(-Inf, [],'Y', fnh, '-Inf Y',  true, -Inf,'Y')
chk(-Inf, [],'R', fnh, '-Inf R',  true, -Inf,'R')
chk(-Inf, [],'Q', fnh, '-Inf Q',  true, -Inf,'Q')
%
%% Fixed Prefix Numeric %%
%
chk(1e-23, [],'', fnh, '0.00000000000000000000001 ', false, 1e-23,'')
%
chk(1000, 1, '', true, fnh, '1000 ', false, 1000,'')
chk(1000, 2, '', true, fnh, '1000 ', false, 1000,'')
chk(1000, 3, '', true, fnh, '1000 ', false, 1000,'')
chk(1000, 4, '', true, fnh, '1000 ', false, 1000,'')
chk(1000, 5, '', true, fnh, '1000.0 ', false, 1000,'')
chk(1000, 6, '', true, fnh, '1000.00 ', false, 1000,'')
chk(1000, 7, '', true, fnh, '1000.000 ', false, 1000,'')
chk(1000, 8, '', true, fnh, '1000.0000 ', false, 1000,'')
chk(1000, 9, '', true, fnh, '1000.00000 ', false, 1000,'')
chk(999.999, 1, '', fnh, '1000 ', false, 1000,'')
chk(999.999, 2, '', fnh, '1000 ', false, 1000,'')
chk(999.999, 3, '', fnh, '1000 ', false, 1000,'')
chk(999.999, 4, '', fnh, '1000 ', false, 1000,'')
chk(999.999, 5, '', fnh, '1000 ', false, 1000,'')
chk(999.999, 6, '', fnh, '999.999 ', false, 999.999,'')
chk(999.999, 7, '', fnh, '999.999 ', false, 999.999,'')
chk(999.999, 8, '', fnh, '999.999 ', false, 999.999,'')
chk(999.999, 9, '', fnh, '999.999 ', false, 999.999,'')
chk(999, 1, 'k', true, fnh, '1 k', true, 1,'k')
chk(999, 2, 'k', true, fnh, '1.0 k', true, 1,'k')
chk(999, 3, 'k', true, fnh, '0.999 k', true, 0.999,'k')
chk(999, 4, 'k', true, fnh, '0.9990 k', true, 0.999,'k')
chk(999, 5, 'k', true, fnh, '0.99900 k', true, 0.999,'k')
chk(999, 6, 'k', true, fnh, '0.999000 k', true, 0.999,'k')
chk(999, 7, 'k', true, fnh, '0.9990000 k', true, 0.999,'k')
chk(999, 8, 'k', true, fnh, '0.99900000 k', true, 0.999,'k')
chk(999, 9, 'k', true, fnh, '0.999000000 k', true, 0.999,'k')
chk(999, 1, 'M', true, fnh, '0.001 M', true, 0.001,'M')
chk(999, 2, 'M', true, fnh, '0.0010 M', true, 0.001,'M')
chk(999, 3, 'M', true, fnh, '0.000999 M', true, 0.000999,'M')
chk(999, 4, 'M', true, fnh, '0.0009990 M', true, 0.000999,'M')
chk(999, 5, 'M', true, fnh, '0.00099900 M', true, 0.000999,'M')
chk(999, 6, 'M', true, fnh, '0.000999000 M', true, 0.000999,'M')
chk(999, 7, 'M', true, fnh, '0.0009990000 M', true, 0.000999,'M')
chk(999, 8, 'M', true, fnh, '0.00099900000 M', true, 0.000999,'M')
chk(999, 9, 'M', true, fnh, '0.000999000000 M', true, 0.000999,'M')
chk(999, 1, 'G', true, fnh, '0.000001 G', true, 0.000001,'G')
chk(999, 2, 'G', true, fnh, '0.0000010 G', true, 0.000001,'G')
chk(999, 3, 'G', true, fnh, '0.000000999 G', true, 0.000000999,'G')
chk(999, 4, 'G', true, fnh, '0.0000009990 G', true, 0.000000999,'G')
chk(999, 5, 'G', true, fnh, '0.00000099900 G', true, 0.000000999,'G')
chk(999, 6, 'G', true, fnh, '0.000000999000 G', true, 0.000000999,'G')
chk(999, 7, 'G', true, fnh, '0.0000009990000 G', true, 0.000000999,'G')
chk(999, 8, 'G', true, fnh, '0.00000099900000 G', true, 0.000000999,'G')
chk(999, 9, 'G', true, fnh, '0.000000999000000 G', true, 0.000000999,'G')
chk(999, 1, 'k',       fnh, '1 k', true, 1,'k')
chk(999, 2, 'k',       fnh, '1 k', true, 1,'k')
chk(999, 3, 'k',       fnh, '0.999 k', true, 0.999,'k')
chk(999, 4, 'k',       fnh, '0.999 k', true, 0.999,'k')
chk(999, 5, 'k',       fnh, '0.999 k', true, 0.999,'k')
chk(999, 6, 'k',       fnh, '0.999 k', true, 0.999,'k')
chk(999, 7, 'k',       fnh, '0.999 k', true, 0.999,'k')
chk(999, 8, 'k',       fnh, '0.999 k', true, 0.999,'k')
chk(999, 9, 'k',       fnh, '0.999 k', true, 0.999,'k')
chk(999, 1, 'M',       fnh, '0.001 M', true, 0.001,'M')
chk(999, 2, 'M',       fnh, '0.001 M', true, 0.001,'M')
chk(999, 3, 'M',       fnh, '0.000999 M', true, 0.000999,'M')
chk(999, 4, 'M',       fnh, '0.000999 M', true, 0.000999,'M')
chk(999, 5, 'M',       fnh, '0.000999 M', true, 0.000999,'M')
chk(999, 6, 'M',       fnh, '0.000999 M', true, 0.000999,'M')
chk(999, 7, 'M',       fnh, '0.000999 M', true, 0.000999,'M')
chk(999, 8, 'M',       fnh, '0.000999 M', true, 0.000999,'M')
chk(999, 9, 'M',       fnh, '0.000999 M', true, 0.000999,'M')
chk(999, 1, 'G',       fnh, '0.000001 G', true, 0.000001,'G')
chk(999, 2, 'G',       fnh, '0.000001 G', true, 0.000001,'G')
chk(999, 3, 'G',       fnh, '0.000000999 G', true, 0.000000999,'G')
chk(999, 4, 'G',       fnh, '0.000000999 G', true, 0.000000999,'G')
chk(999, 5, 'G',       fnh, '0.000000999 G', true, 0.000000999,'G')
chk(999, 6, 'G',       fnh, '0.000000999 G', true, 0.000000999,'G')
chk(999, 7, 'G',       fnh, '0.000000999 G', true, 0.000000999,'G')
chk(999, 8, 'G',       fnh, '0.000000999 G', true, 0.000000999,'G')
chk(999, 9, 'G',       fnh, '0.000000999 G', true, 0.000000999,'G')
%
%% Trailing Zeros %%
%
chk(999.999, 1, '', true, fnh, '1000 ', false, 1000,'')
chk(999.999, 2, '', true, fnh, '1000 ', false, 1000,'')
chk(999.999, 3, '', true, fnh, '1000 ', false, 1000,'')
chk(999.999, 4, '', true, fnh, '1000 ', false, 1000,'')
chk(999.999, 5, '', true, fnh, '1000.0 ', false, 1000,'')
chk(999.999, 6, '', true, fnh, '999.999 ', false, 999.999,'')
chk(999.999, 7, '', true, fnh, '999.9990 ', false, 999.999,'')
chk(999.999, 8, '', true, fnh, '999.99900 ', false, 999.999,'')
chk(999.999, 9, '', true, fnh, '999.999000 ', false, 999.999,'')
chk(999, 1, [], true, fnh, '1 k', true, 1,'k')
chk(999, 2, [], true, fnh, '1.0 k', true, 1,'k')
chk(999, 3, [], true, fnh, '999 ', false, 999,'')
chk(999, 4, [], true, fnh, '999.0 ', false, 999,'')
chk(999, 5, [], true, fnh, '999.00 ', false, 999,'')
chk(999, 6, [], true, fnh, '999.000 ', false, 999,'')
chk(999, 7, [], true, fnh, '999.0000 ', false, 999,'')
chk(999, 8, [], true, fnh, '999.00000 ', false, 999,'')
chk(999, 9, [], true, fnh, '999.000000 ', false, 999,'')
%
%% https://physics.nist.gov/cuu/pdf/sp811.pdf %%
%
chk(3.3e7,   fnh, '33 M')
chk(0.00952, fnh, '9.52 m')
chk(2703,    fnh, '2.703 k')
chk(5.8e-8,  fnh, '58 n')
%
%% https://physics.nist.gov/cuu/Units/prefixes.html %%
%
chk(169, [],  '', fnh, '169 ')
chk(169, [], 'm', fnh, '169000 m')
chk(169, [], 'k', fnh, '0.169 k')
%
%% http://problemsphysics.com/formulas/prefixes.html %%
%
chk(2e-24, fnh, '2 y')
chk(5e-21, fnh, '5 z')
chk(4e-18, fnh, '4 a')
chk(5e-15, fnh, '5 f')
chk(7e-12, fnh, '7 p')
chk(5e-9,  fnh, '5 n')
chk(6e-6,  fnh, '6 µ')
chk(5e-3,  fnh, '5 m')
chk(1.6e3, fnh, '1.6 k')
chk(19e6,  fnh, '19 M')
chk(3e9,   fnh, '3 G')
chk(2e12,  fnh, '2 T')
chk(11e15, fnh, '11 P') % source is inconsistent
chk(4e18,  fnh, '4 E')
chk(12e21, fnh, '12 Z')
chk(21e24, fnh, '21 Y')
%
%% https://si-prefix.readthedocs.io/en/latest/ %%
%
chk(0.5,     1, [], 'dp', fnh, '500.0 m')
chk(0.01331, 2, [], 'dp', fnh, '13.31 m')
chk(1331,    2, [], 'dp', fnh, '1.33 k')
chk(1331,    0, [], 'dp', fnh, '1 k')
%
chk(1e-27,       2, [], 'dp', fnh,   '1.00 r') % source: '1.00e-27 '
chk(1.764e-24,   2, [], 'dp', fnh,   '1.76 y')
chk(7.4088e-23,  2, [], 'dp', fnh,  '74.09 y')
chk(3.1117e-21,  2, [], 'dp', fnh,   '3.11 z')
chk(1.30691e-19, 2, [], 'dp', fnh, '130.69 z')
chk(5.48903e-18, 2, [], 'dp', fnh,   '5.49 a')
chk(2.30539e-16, 2, [], 'dp', fnh, '230.54 a')
chk(9.68265e-15, 2, [], 'dp', fnh,   '9.68 f')
chk(4.06671e-13, 2, [], 'dp', fnh, '406.67 f')
chk(1.70802e-11, 2, [], 'dp', fnh,  '17.08 p')
chk(7.17368e-10, 2, [], 'dp', fnh, '717.37 p')
chk(3.01295e-08, 2, [], 'dp', fnh,  '30.13 n')
chk(1.26544e-06, 2, [], 'dp', fnh,   '1.27 µ')
chk(5.31484e-05, 2, [], 'dp', fnh,  '53.15 µ')
chk(0.00223223,  2, [], 'dp', fnh,   '2.23 m')
chk(0.0937537,   2, [], 'dp', fnh,  '93.75 m')
chk(3.93766,     2, [], 'dp', fnh,    '3.94 ')
chk(165.382,     2, [], 'dp', fnh,  '165.38 ')
chk(6946.03,     2, [], 'dp', fnh,   '6.95 k')
chk(291733,      2, [], 'dp', fnh, '291.73 k')
chk(1.22528e+07, 2, [], 'dp', fnh,  '12.25 M')
chk(5.14617e+08, 2, [], 'dp', fnh, '514.62 M')
chk(2.16139e+10, 2, [], 'dp', fnh,  '21.61 G')
chk(9.07785e+11, 2, [], 'dp', fnh, '907.79 G') % source: '907.78 G'
chk(3.8127e+13,  2, [], 'dp', fnh,  '38.13 T')
chk(1.60133e+15, 2, [], 'dp', fnh,   '1.60 P')
chk(6.7256e+16,  2, [], 'dp', fnh,  '67.26 P')
chk(2.82475e+18, 2, [], 'dp', fnh,   '2.82 E')
chk(1.1864e+20,  2, [], 'dp', fnh, '118.64 E')
chk(4.98286e+21, 2, [], 'dp', fnh,   '4.98 Z')
chk(2.0928e+23,  2, [], 'dp', fnh, '209.28 Z')
chk(8.78977e+24, 2, [], 'dp', fnh,   '8.79 Y')
chk(3.6917e+26,  2, [], 'dp', fnh, '369.17 Y')
chk(1.55051e+28, 2, [], 'dp', fnh,  '15.51 R') % source: '15.51e+27 '
chk(6.51216e+29, 2, [], 'dp', fnh, '651.22 R') % source: '651.22e+27 '
%
%% https://en.wikipedia.org/wiki/Metric_prefix %%
%
chk(25e-6,   fnh, '25 µ')
chk(5.01e-3, fnh, '5.01 m')
chk(3e6,     fnh, '3 M')
%
%% Display Results %%
%
chk()
%
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%num2sip_test